California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 005 - NONVIOLENT DRUG OFFENSES. SENTENCING, PAROLE AND REHABILITATION. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1302707 | NORA CAMPAIGN - YES ON 5, SPONSORED BY CAMPAIGN FOR NEW DRUG POLICIES AND DRUG POLICY ALLIANCE NETWORK | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1312996 | CAMPAIGN AGAINST PROPOSITIONS 4, 6, 8, 9, & FOR PROPOSITION 5 CALIFORNIANS FOR JUSTICE EDUCATION FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1308198 | PEOPLE AGAINST THE PROPOSITION 5 DECEPTION | OPPOSE